﻿using Faker;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;

namespace TestProject1
{
    /// <summary>
    /// Class to hold config infor for using a Mailinator account
    /// </summary>
    public class MailinatorConfig
    {
        /// <summary>
        /// Gets the Mailinator ID from the Mailinator account
        /// </summary>
        public string MailinatorId { get; }

        /// <summary>
        /// SMTP server address used to send an email
        /// </summary>
        public string SmtpServerAddress { get; }

        /// <summary>
        /// Email address used to send an email
        /// </summary>
        public string SendingEmailAddress { get; }

        /// <summary>
        /// App ID provided by a Gmail account to give programmatic access to that account
        /// </summary>
        public string AppId { get; }

        /// <summary>
        /// Mailinator domain name
        /// </summary>
        public string DomainName { get; }

        /// <summary>
        /// Creates a new configuration. The data is read from the specified text file,
        /// each entry on a separate line as follows:
        /// Id provided by Mailinator
        /// Sending SMTP server address
        /// Sending email address
        /// The Google app id(this only works with gmail right now)
        /// The receiveing email domain(e.g., me.testinator.com)
        /// </summary>
        /// <param name="credsFileName">Fully qualified path to the config file</param>
        public MailinatorConfig(string credsFileName)
        {
            var lines = File.ReadAllLines(credsFileName);

            MailinatorId= lines[0];
            SmtpServerAddress= lines[1];
            SendingEmailAddress= lines[2];
            AppId= lines[3];
            DomainName = lines[4];
        }
    }
}
